@@ -16,11 +16,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -28,7 +28,7 @@ our $VERSION = '0.06';
 
   my $config = Config::Abstraction->new(
     config_dirs => ['config'],
-    env_prefix  => 'MYAPP_',
+    env_prefix => 'MYAPP_',
     flatten => 0,
   );
 
@@ -42,8 +42,8 @@ formats (YAML, JSON, XML, and INI),
 it also allows levels of configuration, each of which overrides the lower levels.
 So, it also integrates environment variable
 overrides and command line arguments for runtime configuration adjustments.
-This module is designed to help developers manage layered configurations that can be loaded from files and overridden by environment variables,
-offering a robust and dynamic approach
+This module is designed to help developers manage layered configurations that can be loaded from files and overridden by at run-time for debugging,
+offering a modern, robust and dynamic approach
 to configuration management.
 
 =head2 KEY FEATURES
@@ -183,7 +183,7 @@ Options:
 
 =item * C<config_dirs>
 
-An arrayref of directories to look for configuration files (default: C<['config']>).
+An arrayref of directories to look for configuration files (default: C<[$HOME/.conf]>, C<[$DOCUMENT_ROOT/conf]>, or C<['conf']>).
 
 =item * C<config_file>
 
@@ -191,7 +191,7 @@ Points to a configuration file of any format.
 
 =item * C<config_files>
 
-An arrayref of files to look for in the configration directories.
+An arrayref of files to look for in the configuration directories.
 Put the more important files later,
 since later files override earlier ones.
 
@@ -209,6 +209,10 @@ If true, returns a flat hash structure like C<{database.user}> (default: C<0>) i
 Used for warnings and traces.
 An object that understands warn(), debug() and trace() messages.
 
+=item * C<path>
+
+A synonym of C<config_dirs>.
+
 =item * C<sep_char>
 
 The separator in keys.
@@ -225,12 +229,24 @@ sub new
 	my $class = shift;
 	my $params = Params::Get::get_params(undef, @_) || {};
 
+	$params->{'config_dirs'} //= $params->{'path'};	# Compatability with Config::Auto
+
+	if(!defined($params->{'config_dirs'})) {
+		# Set up the default value for config_dirs
+		if($ENV{'HOME'}) {
+			$params->{'config_dirs'} = [File::Spec->catdir($ENV{'HOME'}, '.conf')];
+		} elsif($ENV{'DOCUMENT_ROOT'}) {
+			$params->{'config_dirs'} = [File::Spec->catdir($ENV{'DOCUMENT_ROOT'}, 'conf')];
+		} else {
+			$params->{'config_durs'} = ['conf'];
+		}
+	}
+
 	my $self = bless {
 		%{$params},
-		config_dirs => $params->{config_dirs} || ['config'],
 		env_prefix => $params->{env_prefix} || 'APP_',
 		flatten	 => $params->{flatten} // 0,
-		config	=> {},
+		config => {},
 		sep_char => '.'
 	}, $class;
 
@@ -246,7 +262,7 @@ sub _load_config
 
 	my $logger = $self->{'logger'};
 
-	for my $dir (@{ $self->{config_dirs} }) {
+	for my $dir (@{$self->{'config_dirs'}}) {
 		for my $file (qw/base.yaml base.yml base.json base.xml base.ini local.yaml local.yml local.json local.xml local.ini/) {
 			my $path = File::Spec->catfile($dir, $file);
 			if($logger) {
@@ -316,7 +332,23 @@ sub _load_config
 					}
 					if(!$data) {
 						$self->_load_driver('YAML::XS', ['LoadFile']);
-						$data = LoadFile($path);
+						if(($data = LoadFile($path)) && (ref($data) eq 'HASH')) {
+							# Could be colon file, could be YAML, whichever it is, break the configuration fields
+							foreach my($k, $v) (%{$data}) {
+								next if($v =~ /^".+"$/);	# Quotes to keep in one field
+								if($v =~ /,/) {
+									my @vals = split(/\s*,\s*/, $v);
+									delete $data->{$k};
+									foreach my $val (@vals) {
+										if($val =~ /(.+)=(.+)/) {
+											$data->{$k}{$1} = $2;
+										} else {
+											$data->{$k}{$val} = 1;
+										}
+									}
+								}
+							}
+						}
 						if((!$data) || (ref($data) ne 'HASH')) {
 							$self->_load_driver('Config::IniFiles');
 							if(my $ini = Config::IniFiles->new(-file => $path)) {
@@ -348,7 +380,7 @@ sub _load_config
 					if($data) {
 						%merged = %{ merge( $data, \%merged ) };
 					}
-				} else {
+				} elsif($data) {
 					%merged = %{$data};
 				}
 				if($merged{'config_path'}) {
